==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/GridSelectionChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSelectionChangedEventArgsDescription } from "./GridSelectionChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridSelectionChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridSelectionChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridSelectionChangedEventArgsDescriptionMetadata.a == null) {
                GridSelectionChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridSelectionChangedEventArgsDescriptionMetadata.c(GridSelectionChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(GridSelectionChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(GridSelectionChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            GridSelectionChangedEventArgsDescriptionMetadata.b(a);
            a.aa("GridSelectionChangedEventArgs", () => new GridSelectionChangedEventArgsDescription());
            a.z("GridSelectionChangedEventArgs", GridSelectionChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridSelectionChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridSelectionChangedEventArgsDescriptionMetadata, 'GridSelectionChangedEventArgsDescriptionMetadata');
    GridSelectionChangedEventArgsDescriptionMetadata.a = null;
    return GridSelectionChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GridSelectionChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSelectionChangedEventArgsDescription } from "./GridSelectionChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridSelectionChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridSelectionChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridSelectionChangedEventArgsDescriptionMetadata.a == null) {
                GridSelectionChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridSelectionChangedEventArgsDescriptionMetadata.c(GridSelectionChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridSelectionChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(GridSelectionChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            GridSelectionChangedEventArgsDescriptionMetadata.b(a);
            a.ac("GridSelectionChangedEventArgs", () => new GridSelectionChangedEventArgsDescription());
            a.ab("GridSelectionChangedEventArgs", GridSelectionChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridSelectionChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridSelectionChangedEventArgsDescriptionMetadata, 'GridSelectionChangedEventArgsDescriptionMetadata');
    GridSelectionChangedEventArgsDescriptionMetadata.a = null;
    return GridSelectionChangedEventArgsDescriptionMetadata;
})();
